==> rx-node-1.0.0.tgz: package/readme.md <==
# rx-node - RxJS bindings for Node.js and io.js #

## OVERVIEW

This project provides Reactive Extensions for JavaScript (RxJS) bindings for [Node.js](http://nodejs.org) and [io.js](https://iojs.org) to abstract over the `EventEmitter`, Streams and more.  

## GETTING STARTED

There are a number of ways to get started with the RxJS bindings for Node.js and io.js.

### Download the Source

To download the source of the HTML DOM Bindings for the Reactive Extensions for JavaScript, type in the following:
```bash
git clone https://github.com/Reactive-Extensions/rx-node.git
cd ./rxjs-dom
```
### Installing with [NPM](https://npmjs.org/)
```bash
npm install rx-dom
```
##  API Documentation ##

You can find the documentation [here](https://github.com/Reactive-Extensions/rx-node/tree/master/doc) as well as examples [here](https://github.com/Reactive-Extensions/rx-node/tree/master/examples).

## Contributing ##

There are lots of ways to [contribute](https://github.com/Reactive-Extensions/rx-node/wiki/Contributing) to the project, and we appreciate our [contributors](https://github.com/Reactive-Extensions/rx-node/wiki/Contributors).

You can contribute by reviewing and sending feedback on code checkins, suggesting and trying out new features as they are implemented, submit bugs and help us verify fixes as they are checked in, as well as submit code fixes or code contributions of your own. Note that all code submissions will be rigorously reviewed and tested by the Rx Team, and only those that meet an extremely high bar for both quality and design/roadmap appropriateness will be merged into the source.

## LICENSE

Copyright Microsoft Open Technologies

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

==> rx-node-1.0.1.tgz: package/readme.md <==
# rx-node - RxJS bindings for Node.js and io.js #

## OVERVIEW

This project provides Reactive Extensions for JavaScript (RxJS) bindings for [Node.js](http://nodejs.org) and [io.js](https://iojs.org) to abstract over the `EventEmitter`, Streams and more.

## GETTING STARTED

There are a number of ways to get started with the RxJS bindings for Node.js and io.js.

### Download the Source

To download the source of the Node.js Bindings for the Reactive Extensions for JavaScript, type in the following:
```bash
git clone https://github.com/Reactive-Extensions/rx-node.git
cd ./rxjs-node
```
### Installing with [NPM](https://npmjs.org/)
```bash
npm install rx-node
```
##  API Documentation ##

You can find the documentation [here](https://github.com/Reactive-Extensions/rx-node/tree/master/doc).

## Contributing ##

There are lots of ways to [contribute](https://github.com/Reactive-Extensions/rx-node/wiki/Contributing) to the project, and we appreciate our [contributors](https://github.com/Reactive-Extensions/rx-node/wiki/Contributors).

You can contribute by reviewing and sending feedback on code checkins, suggesting and trying out new features as they are implemented, submit bugs and help us verify fixes as they are checked in, as well as submit code fixes or code contributions of your own. Note that all code submissions will be rigorously reviewed and tested by the Rx Team, and only those that meet an extremely high bar for both quality and design/roadmap appropriateness will be merged into the source.

## LICENSE

Copyright Microsoft Open Technologies

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
